package controllers

import (
	"encoding/json"
	"hongze/hz_data_api/models"
	"hongze/hz_data_api/utils"
)

// 指标
type EdbInfoController struct {
	BaseAuthController
}

// @Title 获取基础指标详情
// @Description 获取基础指标详情
// @Param	request	body models.EdbInfoDetailReq true "type json string"
// @Success 200 {object} models.EdbInfo
// @router /detail [post]
func (this *EdbInfoController) EdbIndexDetail() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	var req models.EdbInfoDetailReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}

	if req.EdbCode == "" {
		br.Msg = "请输入指标编码！"
		return
	}
	detail, err := models.GetEdbInfoByEdbCode(req.EdbCode)
	if err != nil {
		br.Msg = "获取数据失败！"
		br.ErrMsg = "获取数据失败，Err:" + err.Error()
		return
	}

	calculateList, err := models.GetEdbInfoCalculateMapping(req.EdbCode)
	if err != nil && err.Error() != utils.ErrNoRow() {
		br.Msg = "获取数据失败！"
		br.ErrMsg = "获取计算指标失败，Err:" + err.Error()
		return
	}
	for _, v := range calculateList {
		baseEdbInfoList, err := models.GetEdbInfoCalculateBaseEdbInfo(v.EdbCode)
		if err != nil && err.Error() != utils.ErrNoRow() {
			br.Msg = "获取数据失败！"
			br.ErrMsg = "获取计算指标所依赖的基础指标编码失败，Err:" + err.Error()
			return
		}
		v.BaseEdbInfoCode = baseEdbInfoList
	}
	detail.CalculateList = calculateList
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = detail
}
