package services

import (
	"github.com/rdlucklib/rdluck_tools/paging"
	"hongze/hz_data_api/models"
	"hongze/hz_data_api/utils"
)

func GetIndexList(source int, startDate, endDate string) (list interface{}, err error) {
	switch source {
	case utils.DATA_SOURCE_ZZ:
		list, err = models.GetTradeZhengzhouIndex(startDate, endDate)
	case utils.DATA_SOURCE_DL:
		list, err = models.GetTradeDalianIndex(startDate, endDate)
	case utils.DATA_SOURCE_SH:
		list, err = models.GetTradeShanghaiIndex(startDate, endDate)
	case utils.DATA_SOURCE_CFFEX:
		list, err = models.GetTradeCffexIndex(startDate, endDate)
	case utils.DATA_SOURCE_SHFE:
		list, err = models.GetTradeIneIndex(startDate, endDate)
	case utils.DATA_SOURCE_GOOGLE_TRAVEL:
		list, err = models.GetChangesVisitorsCovid(startDate, endDate)
	case utils.DATA_SOURCE_EIA_STEO:
		list, err = models.GetEiaSteoIndex(startDate, endDate)
	case utils.DATA_SOURCE_COM_TRADE:
		indexList := make([]*models.ComTradeIndex, 0)
		mappingList := make([]*models.ComTradeCodeMapping, 0)

		indexList, err = models.GetComTradeIndex(startDate, endDate)
		if err != nil {
			return
		}
		mappingList, err = models.GetComTradeCodeMappingList(startDate, endDate)
		if err != nil {
			return
		}

		list = models.ComTradeIndexAndDataResp{
			IndexList:   indexList,
			MappingList: mappingList,
		}
	default:
	}
	return
}

func GetIndexDataList(source int, indexCode, startDate, endDate string) (list interface{}, err error) {
	switch source {
	case utils.DATA_SOURCE_EIA_STEO:
		list, err = models.GetEiaSteoIndexData(indexCode, startDate, endDate)
	case utils.DATA_SOURCE_THS:
		list, err = models.GetEdbDataThs(indexCode, startDate, endDate)
	case utils.DATA_SOURCE_PB, utils.DATA_SOURCE_PB_FINANCE:
		list, err = models.GetEdbDataPb(indexCode, startDate, endDate)
	default:
	}
	return
}

// GetIndexDataPageList 分页获取数据同步
func GetIndexDataPageList(source, currPage, pageSize int, startDate, endDate string) (list interface{}, err error) {
	switch source {
	case utils.DATA_SOURCE_COM_TRADE:
		var total int
		dataList := make([]*models.ComTradeData, 0)
		total, dataList, err = models.GetComTradeDataList(startDate, endDate, currPage*pageSize, pageSize)
		if err != nil {
			return
		}
		page := paging.GetPaging(currPage, pageSize, total)
		list = models.ComTradeIndexDataResp{
			List:   dataList,
			Paging: page,
		}
	default:
	}
	return
}
